shill: Use integer types from stdint.h

This CL replaces the deprecated int* and uint* types from
'base/basictypes.h' with the int*_t and uint*_t types from 'stdint.h'.

BUG=chromium:401356
TEST=`USE='cellular gdmwimax wimax' FEATURES=test emerge-$BOARD platform2`

Change-Id: I3d4c195881203dd2a47dbb5af150b6c90b9c206e
Reviewed-on: https://chromium-review.googlesource.com/211770
Reviewed-by: Mike Frysinger <vapier@chromium.org>
Commit-Queue: Ben Chan <benchan@chromium.org>
Tested-by: Ben Chan <benchan@chromium.org>
diff --git a/arp_client.cc b/arp_client.cc
index f25d91b..eb7605a 100644
--- a/arp_client.cc
+++ b/arp_client.cc
@@ -17,8 +17,8 @@
 
 namespace shill {
 
-// ARP opcode is the last uint16 in the ARP header.
-const size_t ArpClient::kArpOpOffset = sizeof(arphdr) - sizeof(uint16);
+// ARP opcode is the last uint16_t in the ARP header.
+const size_t ArpClient::kArpOpOffset = sizeof(arphdr) - sizeof(uint16_t);
 
 // The largest packet we expect is one with IPv6 addresses in it.
 const size_t ArpClient::kMaxArpPacketLength =